==> babelator-0.2.11.tgz: package/lib/index.js <==
'use strict';

//region Imports
var path = require('path');
var _ = require('lodash');
var chalk = require('chalk');
var config = require('./config');
var fs = require('fs');
//endregion

module.exports = main;

////////////////////////////////////////////////////////////////////////////////

var tasksDir = './tasks';

function main(gulp) {

  var FwdRef = require('undertaker-forward-reference');

  // This allows forward references to tasks.
  var fwdReferenceRegistry = new FwdRef();
  var registry = fwdReferenceRegistry;
  gulp.registry(fwdReferenceRegistry);

  require('gulp-help')(gulp, {
    hideDefaultTask: true,
    hideEmpty: true });

  //////////////////////////////////////////////////////////////////////////////

  // TODO(vjpr): Extract common `src/dist` paths.
  // Doesn't exist yet...https://github.com/chmontgomery/gulp-help/issues/36
  var opts = config();

  // TODO(vjpr): Maybe make this a setter and enforce who can change it and when for better safety.
  // Globally stores the config profile to use when running tasks. Tasks using the `getOpts` function will receive `opts` for this particular profile.
  gulp.profile = null;

  // This function is the 3rd argument passed to each task module. This function *should* be called inside each task, allowing task-specific configuration.
  function getOpts() {
    if (!gulp.profile) return opts;
    if (!opts[gulp.profile]) {
      console.error('A profile was activated (by setting `gulp.profile`) but the profile configuration is missing (from `babelator.js`).');
      process.exit(1);
      return;
    }
    return opts[gulp.profile];
  }

  //////////////////////////////////////////////////////////////////////////////

  // Require all modules in `./tasks` dir, and pass `gulp` and `opts` to each module.

  var fullDir = path.join(__dirname, tasksDir);
  var modules = requireDir(fullDir);
  _(modules).forEach(function (module) {
    module(gulp, opts, getOpts);
  });

  gulp.task('default', gulp.series('help'));
  gulp.task('compile', d('Compile ' + chalk.bold(opts.srcDir) + ' to ' + chalk.bold(opts.destDir), gulp.series('lib:compile')));
  gulp.task('test', d('Compile and run tests on transpiled tests', gulp.series('mocha:lib')));
  gulp.task('test-src', d('Run tests using glob: ' + chalk.bold(opts.testsGlob), gulp.series('mocha:src')));
  gulp.task('watch', d('Compile on file change', gulp.series('lib:watch')));
  gulp.task('test-watch', d('Compile and run tests on file change', gulp.series('test:watch')));
  gulp.task('build', d('Clean and compile', gulp.series('lib:clean', 'lib:compile')));
  gulp.task('show-config', d('Show resolved config settings', function (done) {
    console.log('\n' + chalk.underline('Resolved config') + '\n');
    pp(opts);
    console.log('');
    var p = config.getConfigPath();
    if (fs.existsSync(p)) {
      console.log('Using config from:', chalk.bold(p));
      console.log('All possible config options can be found by looking in:', chalk.bold(tasksDir));
    } else {
      console.log('To modify config created file:', p);
    }
    console.log('');
    done();
  }));

  // Run all tasks ending with `:bootstrap`.
  var bootstrapTasks = _(registry._tasks).filter(function (v, k) {
    return _.endsWith(k, ':bootstrap');
  }).value();
  gulp.task('bootstrap', gulp.series(_.values(bootstrapTasks)));
  gulp.task('prepublish', gulp.series('npm:prepublish'));
}

////////////////////////////////////////////////////////////////////////////////
// Utilities
////////////////////////////////////////////////////////////////////////////////

function pp() {
  var prettyjson = require('prettyjson');

  console.log(prettyjson.render.apply(prettyjson, arguments));
}

function requireDir(fullDir) {
  return require('fs').readdirSync(fullDir).map(function (entry) {
    try {
      return require(path.join(fullDir, entry));
    } catch (e) {
      if (e.name !== 'MODULE_NOT_FOUND') {
        throw e;
      }
    }
  });
}

function d(description, fn) {
  fn.description = description;
  return fn;
}

////////////////////////////////////////////////////////////////////////////////

==> babelator-0.2.21.tgz: package/lib/index.js <==
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = main;

////////////////////////////////////////////////////////////////////////////////

var tasksDir = './tasks';

// opts - Allows config to be passed in from the gulpfile. However, it is better
//   to use the babelator.js config file because it allows us to not rely on
//   gulp in the future.
function main(gulp) {
  var opts = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];


  var FwdRef = require('undertaker-forward-reference');

  // This allows forward references to tasks.
  var fwdReferenceRegistry = new FwdRef();
  var registry = fwdReferenceRegistry;
  gulp.registry(fwdReferenceRegistry);

  require('gulp-help')(gulp, {
    hideDefaultTask: true,
    hideEmpty: true });

  //////////////////////////////////////////////////////////////////////////////

  // TODO(vjpr): Extract common `src/dist` paths.
  opts = (0, _config2.default)(opts);

  // TODO(vjpr): Maybe make this a setter and enforce who can change it and when for better safety.
  // Globally stores the config profile to use when running tasks. Tasks using the `getOpts` function will receive `opts` for this particular profile.
  gulp.profile = null;

  // This function is the 3rd argument passed to each task module. This function *should* be called inside each task, allowing task-specific configuration.
  function getOpts() {
    if (!gulp.profile) return opts;
    if (!opts[gulp.profile]) {
      console.error('A profile was activated (by setting `gulp.profile`) but the profile configuration is missing (from `babelator.js`).');
      process.exit(1);
      return;
    }
    return opts[gulp.profile];
  }

  //////////////////////////////////////////////////////////////////////////////

  // Require all modules in `./tasks` dir, and pass `gulp` and `opts` to each module.

  var fullDir = _path2.default.join(__dirname, tasksDir);
  var modules = requireDir(fullDir);
  (0, _lodash2.default)(modules).forEach(function (module) {
    module.task && module.task(gulp, opts, getOpts);
  });

  gulp.task('default', gulp.series('help'));
  gulp.task('compile', d('Compile ' + _chalk2.default.bold(opts.srcDir) + ' to ' + _chalk2.default.bold(opts.destDir), gulp.series('lib:compile')));
  gulp.task('test', d('Compile and run tests on transpiled tests', gulp.series('mocha:lib')));
  gulp.task('test-src', d('Run tests using glob: ' + _chalk2.default.bold(opts.testsGlob), gulp.series('mocha:src')));
  gulp.task('watch', d('Compile on file change', gulp.series('lib:watch')));
  gulp.task('test-watch', d('Compile and run tests on file change', gulp.series('test:watch')));
  gulp.task('build', d('Clean and compile', gulp.series('lib:clean', 'lib:compile')));
  gulp.task('show-config', d('Show resolved config settings', function (done) {
    console.log('\n' + _chalk2.default.underline('Resolved config') + '\n');
    pp(opts);
    console.log('');
    var p = _config2.default.getConfigPath();
    if (_fs2.default.existsSync(p)) {
      console.log('Using config from:', _chalk2.default.bold(p));
      console.log('All possible config options can be found by looking in:', _chalk2.default.bold(tasksDir));
    } else {
      console.log('To modify config created file:', p);
    }
    console.log('');
    done();
  }));

  // Run all tasks ending with `:bootstrap`.
  // TODO(vjpr): Deprecated. We now use Yeoman Generators.
  var bootstrapTasks = (0, _lodash2.default)(registry._tasks).filter(function (v, k) {
    return _lodash2.default.endsWith(k, ':bootstrap');
  }).value();
  gulp.task('bootstrap', gulp.series(_lodash2.default.values(bootstrapTasks)));
  gulp.task('prepublish', gulp.series('npm:prepublish'));
}

////////////////////////////////////////////////////////////////////////////////
// Utilities
////////////////////////////////////////////////////////////////////////////////

function pp() {
  var prettyjson = require('prettyjson');

  console.log(prettyjson.render.apply(prettyjson, arguments));
}

function requireDir(fullDir) {
  return require('fs').readdirSync(fullDir).map(function (entry) {
    try {
      return require(_path2.default.join(fullDir, entry));
    } catch (e) {
      if (e.name !== 'MODULE_NOT_FOUND') {
        throw e;
      }
    }
  });
}

function d(description, fn) {
  fn.description = description;
  return fn;
}

////////////////////////////////////////////////////////////////////////////////
